@@ -7,9 +7,11 @@ import qualified GI.GObject.Config as GObject
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "Atk"
         version = "1.0"
+        pkgName = "gi-atk"
+        pkgVersion = "2.0.24"
         overridesFile = Just "Atk.overrides"
         verbose = False
         outputDir = Nothing
